A simple framework for authoring conformance test suites.
Structs
- Whether or not the test case passed along with metadata that they results renderer can make use of when rendering our the results of the conformance test.
- The results of all of the test cases in the test suite that was run.
- A test suite to run.
- Constructs an HTML visualization of a test suite.
- A basic list of passing and failing tests, useful for visualizing in a terminal.
Traits
- Used to indicate a type that can be used to create test cases to test some aspect of a Renderer.
Functions
- Run a test suite.